@@ -43,8 +43,8 @@ class QAStage(Stage):
         self.stage_type = data.get("stage_type")
         self.corpus = {}
         corpus = data.get(self.__CORPUS__)
-        for k, v in corpus.items():
-            self.corpus[k.replace(" ", "")] = v.replace(" ", "")
+        # for k, v in corpus.items():
+        #     self.corpus[k.replace(" ", "")] = v.replace(" ", "")
 
         #
         self.questions = get_value_from_dict_by_multi_name(d=data, names=__QUESTIONS_LABEL__)
