@@ -178,10 +178,10 @@ class Stage:
                         sys_reply_complete_refactor += str(var_value)
 
                 except KeyError:
-                    sys_reply_complete_refactor += var
+                    sys_reply_complete_refactor += f" {var}"
             else:
                 var = var.replace(__NEXT_LINE__, "\n")
-                sys_reply_complete_refactor += var
+                sys_reply_complete_refactor += f" {var}"
         return sys_reply_complete_refactor
 
     def run(self, **kwargs):
